pub enum InterceptOutcome {
Continue(InterceptRequest),
Complete(Response<HyperBody>),
}Expand description
The type returned by an OutboundHttpInterceptor.
Variants
Continue(InterceptRequest)
The intercepted request will be passed on to the default outgoing request handler.
Complete(Response<HyperBody>)
The given response will be returned as the result of the intercepted request, bypassing the default handler.